@@ -10,7 +10,7 @@ describe Formatter do
   let(:four_minutes_ago)      { -240 }
   let(:one_minute_ago)        { -60 }
 
-  context 'the %% flag' do
+  context 'with the %% flag' do
     let(:format) { Format::String.new('%%') }
 
     it 'displays a literal percent sign' do
@@ -20,13 +20,13 @@ describe Formatter do
     end
   end
 
-  context 'the %a flag' do
+  context 'with the %a flag' do
     let(:format) { Format::String.new('%a') }
 
     it 'is "--:--:--" when displayed after starting the bar and then resetting the bar' do
       progressbar = ProgressBar::Base.new
 
-      Timecop.travel(to_the_past) do
+      Timecop.freeze(to_the_past) do
         progressbar.start
       end
 
@@ -38,7 +38,7 @@ describe Formatter do
     it 'is the time elapsed when displayed after starting the bar' do
       progressbar = ProgressBar::Base.new(:throttle_rate => 0.0)
 
-      Timecop.travel(to_the_past) do
+      Timecop.freeze(to_the_past) do
         progressbar.start
       end
 
@@ -48,11 +48,11 @@ describe Formatter do
     it 'is the total amount of time elapsed once the bar finishes' do
       progressbar = ProgressBar::Base.new(:throttle_rate => 0.0)
 
-      Timecop.travel(four_minutes_ago) do
+      Timecop.freeze(four_minutes_ago) do
         progressbar.start
       end
 
-      Timecop.travel(one_minute_ago) do
+      Timecop.freeze(one_minute_ago) do
         progressbar.finish
       end
 
@@ -60,7 +60,7 @@ describe Formatter do
     end
   end
 
-  context 'the %b flag' do
+  context 'with the %b flag' do
     let(:format) { Format::String.new('%b') }
 
     it 'is the bar (excluding incomplete space)' do
@@ -69,7 +69,7 @@ describe Formatter do
     end
   end
 
-  context 'the %B flag' do
+  context 'with the %B flag' do
     let(:format) { Format::String.new('%B') }
 
     it 'is the bar (including incomplete space)' do
@@ -79,7 +79,7 @@ describe Formatter do
     end
   end
 
-  context 'the %c flag' do
+  context 'with the %c flag' do
     let(:format) { Format::String.new('%c') }
 
     it 'is the current capacity/progress' do
@@ -93,7 +93,7 @@ describe Formatter do
     end
   end
 
-  context 'the %C flag' do
+  context 'with the %C flag' do
     let(:format) { Format::String.new('%C') }
 
     it 'is the total capacity/progress' do
@@ -109,7 +109,7 @@ describe Formatter do
     end
   end
 
-  context 'the %e flag' do
+  context 'with the %e flag' do
     let(:format) { Format::String.new('%e') }
 
     it 'is unknown estimated time when called before the bar is started' do
@@ -127,7 +127,7 @@ describe Formatter do
     it 'is "??:??:??" when called after the bar is started makes progress and reset' do
       progressbar = ProgressBar::Base.new
 
-      Timecop.travel(to_the_past) do
+      Timecop.freeze(to_the_past) do
         progressbar.start
         progressbar.progress = 50
       end
@@ -140,7 +140,7 @@ describe Formatter do
     it 'is the estimated time remaining when called after the bar is started' do
       progressbar = ProgressBar::Base.new(:smoothing => 0.0)
 
-      Timecop.travel(to_the_past) do
+      Timecop.freeze(to_the_past) do
         progressbar.start
         progressbar.progress = 50
       end
@@ -151,7 +151,7 @@ describe Formatter do
     it 'is "??:??:??" when it could take 100 hours or longer to finish' do
       progressbar = ProgressBar::Base.new(:total => 100, :smoothing => 0.0)
 
-      Timecop.travel(one_hundred_hours_ago) do
+      Timecop.freeze(one_hundred_hours_ago) do
         progressbar.start
         progressbar.progress = 50
       end
@@ -162,11 +162,11 @@ describe Formatter do
     it 'is the total amount of time elapsed once the bar finishes' do
       progressbar = ProgressBar::Base.new(:throttle_rate => 0.0)
 
-      Timecop.travel(four_minutes_ago) do
+      Timecop.freeze(four_minutes_ago) do
         progressbar.start
       end
 
-      Timecop.travel(one_minute_ago) do
+      Timecop.freeze(one_minute_ago) do
         progressbar.finish
       end
 
@@ -174,7 +174,7 @@ describe Formatter do
     end
   end
 
-  context 'the %E flag' do
+  context 'with the %E flag' do
     let(:format) { Format::String.new('%E') }
 
     it 'is unknown estimated time when called before the bar is started' do
@@ -192,7 +192,7 @@ describe Formatter do
     it 'is "??:??:??" when called after the bar is started makes progress and reset' do
       progressbar = ProgressBar::Base.new
 
-      Timecop.travel(to_the_past) do
+      Timecop.freeze(to_the_past) do
         progressbar.start
         progressbar.progress = 50
       end
@@ -205,7 +205,7 @@ describe Formatter do
     it 'is the estimated time remaining when called after the bar is started' do
       progressbar = ProgressBar::Base.new(:smoothing => 0.0)
 
-      Timecop.travel(to_the_past) do
+      Timecop.freeze(to_the_past) do
         progressbar.start
         progressbar.progress = 50
       end
@@ -216,11 +216,11 @@ describe Formatter do
     it 'is the total amount of time elapsed once the bar finishes' do
       progressbar = ProgressBar::Base.new(:throttle_rate => 0.0)
 
-      Timecop.travel(four_minutes_ago) do
+      Timecop.freeze(four_minutes_ago) do
         progressbar.start
       end
 
-      Timecop.travel(one_minute_ago) do
+      Timecop.freeze(one_minute_ago) do
         progressbar.finish
       end
 
@@ -230,7 +230,7 @@ describe Formatter do
     it 'is "> 4 Days" when it could take 100 hours or longer to finish' do
       progressbar = ProgressBar::Base.new(:total => 100, :smoothing => 0.0)
 
-      Timecop.travel(one_hundred_hours_ago) do
+      Timecop.freeze(one_hundred_hours_ago) do
         progressbar.start
         progressbar.progress = 50
       end
@@ -239,7 +239,7 @@ describe Formatter do
     end
   end
 
-  context 'the %f flag' do
+  context 'with the %f flag' do
     let(:format) { Format::String.new('%f') }
 
     it 'is unknown estimated time when called before the bar is started' do
@@ -257,7 +257,7 @@ describe Formatter do
     it 'is "??:??:??" when called after the bar is started makes progress and reset' do
       progressbar = ProgressBar::Base.new
 
-      Timecop.travel(to_the_past) do
+      Timecop.freeze(to_the_past) do
         progressbar.start
         progressbar.progress = 50
       end
@@ -270,7 +270,7 @@ describe Formatter do
     it 'is the estimated time remaining when called after the bar is started' do
       progressbar = ProgressBar::Base.new(:smoothing => 0.0)
 
-      Timecop.travel(to_the_past) do
+      Timecop.freeze(to_the_past) do
         progressbar.start
         progressbar.progress = 50
       end
@@ -281,7 +281,7 @@ describe Formatter do
     it 'is the exact estimated time when it could take 100 hours or longer to finish' do
       progressbar = ProgressBar::Base.new(:total => 100, :smoothing => 0.0)
 
-      Timecop.travel(one_hundred_hours_ago) do
+      Timecop.freeze(one_hundred_hours_ago) do
         progressbar.start
         progressbar.progress = 50
       end
@@ -290,7 +290,7 @@ describe Formatter do
     end
   end
 
-  context 'the %i flag' do
+  context 'with the %i flag' do
     let(:format) { Format::String.new('%i') }
 
     it 'is the incomplete space' do
@@ -331,7 +331,7 @@ describe Formatter do
     end
   end
 
-  context 'the %j flag' do
+  context 'with the %j flag' do
     let(:format) { Format::String.new('%j') }
 
     it 'is the justified percentage complete floored to the nearest whole number' do
@@ -353,7 +353,7 @@ describe Formatter do
     end
   end
 
-  context 'the %J flag' do
+  context 'with the %J flag' do
     let(:format) { Format::String.new('%J') }
 
     it 'is the justified percentage complete floored to two decimal places' do
@@ -375,7 +375,7 @@ describe Formatter do
     end
   end
 
-  context 'the %p flag' do
+  context 'with the %p flag' do
     let(:format) { Format::String.new('%p') }
 
     it 'is the percentage complete floored to the nearest whole number' do
@@ -397,7 +397,7 @@ describe Formatter do
     end
   end
 
-  context 'the %P flag' do
+  context 'with the %P flag' do
     let(:format) { Format::String.new('%P') }
 
     it 'is the percentage complete floored to two decimal places' do
@@ -425,7 +425,7 @@ describe Formatter do
     end
   end
 
-  context 'the %r flag' do
+  context 'with the %r flag' do
     let(:format) { Format::String.new('%r') }
 
     it 'is the rate' do
@@ -435,7 +435,7 @@ describe Formatter do
         progressbar.start
         progressbar.progress += 20
 
-        Timecop.travel(2) do
+        Timecop.freeze(2) do
           expect(Formatter.process(format, 100, progressbar)).to eql '10'
         end
       end
@@ -452,7 +452,7 @@ describe Formatter do
     it 'is zero when no progress has been made' do
       progressbar = ProgressBar::Base.new(:starting_at => 20)
 
-      Timecop.travel(2) do
+      Timecop.freeze(2) do
         expect(Formatter.process(format, 100, progressbar)).to eql '0'
       end
     end
@@ -464,7 +464,7 @@ describe Formatter do
         progressbar.start
         progressbar.progress += 20
 
-        Timecop.travel(2) do
+        Timecop.freeze(2) do
           expect(Formatter.process(format, 100, progressbar)).to eql '10'
         end
       end
@@ -477,7 +477,7 @@ describe Formatter do
         progressbar.start
         progressbar.progress += 20
 
-        Timecop.travel(2) do
+        Timecop.freeze(2) do
           expect(Formatter.process(format, 100, progressbar)).to eql '5'
         end
       end
@@ -487,7 +487,7 @@ describe Formatter do
       progressbar = ProgressBar::Base.new(:starting_at => 20,
                                           :rate_scale  => lambda { |rate| rate / 2 })
 
-      Timecop.travel(2) do
+      Timecop.freeze(2) do
         expect(Formatter.process(format, 100, progressbar)).to eql '0'
       end
     end
@@ -500,14 +500,14 @@ describe Formatter do
         progressbar.start
         progressbar.progress += 20
 
-        Timecop.travel(2) do
+        Timecop.freeze(2) do
           expect(Formatter.process(format, 100, progressbar)).to eql '5'
         end
       end
     end
   end
 
-  context 'the %R flag' do
+  context 'with the %R flag' do
     let(:format) { Format::String.new('%R') }
 
     it 'is the rate' do
@@ -517,7 +517,7 @@ describe Formatter do
         progressbar.start
         progressbar.progress += 10
 
-        Timecop.travel(6) do
+        Timecop.freeze(6) do
           expect(Formatter.process(format, 100, progressbar)).to eql '1.67'
         end
       end
@@ -534,7 +534,7 @@ describe Formatter do
     it 'is zero when no progress has been made' do
       progressbar = ProgressBar::Base.new(:starting_at => 20)
 
-      Timecop.travel(2) do
+      Timecop.freeze(2) do
         expect(Formatter.process(format, 100, progressbar)).to eql '0.00'
       end
     end
@@ -546,7 +546,7 @@ describe Formatter do
         progressbar.start
         progressbar.progress += 13
 
-        Timecop.travel(2) do
+        Timecop.freeze(2) do
           expect(Formatter.process(format, 100, progressbar)).to eql '6.50'
         end
       end
@@ -559,7 +559,7 @@ describe Formatter do
         progressbar.start
         progressbar.progress += 10
 
-        Timecop.travel(6) do
+        Timecop.freeze(6) do
           expect(Formatter.process(format, 100, progressbar)).to eql '0.83'
         end
       end
@@ -569,7 +569,7 @@ describe Formatter do
       progressbar = ProgressBar::Base.new(:starting_at => 20,
                                           :rate_scale  => lambda { |rate| rate / 2 })
 
-      Timecop.travel(2) do
+      Timecop.freeze(2) do
         expect(Formatter.process(format, 100, progressbar)).to eql '0.00'
       end
     end
@@ -582,14 +582,14 @@ describe Formatter do
         progressbar.start
         progressbar.progress += 13
 
-        Timecop.travel(2) do
+        Timecop.freeze(2) do
           expect(Formatter.process(format, 100, progressbar)).to eql '3.25'
         end
       end
     end
   end
 
-  context 'the %t flag' do
+  context 'with the %t flag' do
     let(:format) { Format::String.new('%t') }
 
     it 'is the title' do
@@ -599,7 +599,7 @@ describe Formatter do
     end
   end
 
-  context 'the %T flag' do
+  context 'with the %T flag' do
     let(:format) { Format::String.new('%T') }
 
     it 'is the title' do
@@ -609,7 +609,7 @@ describe Formatter do
     end
   end
 
-  context 'the %u flag' do
+  context 'with the %u flag' do
     let(:format) { Format::String.new('%u') }
 
     it 'is "??" when the total is unknown' do
@@ -619,7 +619,28 @@ describe Formatter do
     end
   end
 
-  context 'the %w flag' do
+  context 'with the %W flag' do
+    let(:format) { Format::String.new('%W') }
+
+    it 'is the bar with percentage (including incomplete space)' do
+      progressbar = ProgressBar::Base.new(:length => 100)
+
+      expect(Formatter.process(format, 100, progressbar)).to eql ' ' * 100
+      4.times { progressbar.increment }
+      expect(Formatter.process(format, 100, progressbar)).to eql "====#{' ' * 96}"
+      progressbar.increment
+      expect(Formatter.process(format, 100, progressbar)).to eql "= 5 =#{' ' * 95}"
+      5.times { progressbar.increment }
+      expect(Formatter.process(format, 100, progressbar)).to eql "=== 10 ===#{' ' * 90}"
+      progressbar.decrement
+      expect(Formatter.process(format, 100, progressbar)).to eql "=== 9 ===#{' ' * 91}"
+      91.times { progressbar.increment }
+      expect(Formatter.process(format, 100, progressbar)).to eql \
+        "#{'=' * 47} 100 #{'=' * 48}"
+    end
+  end
+
+  context 'with the %w flag' do
     let(:format) { Format::String.new('%w') }
 
     it 'is the bar with the percentage' do
@@ -640,7 +661,7 @@ describe Formatter do
     end
   end
 
-  context 'combined flags' do
+  context 'with combined flags' do
     it 'is the whole bar when combining both the bar and incomplete space flags' do
       format      = Format::String.new('%b%i')
       progressbar = ProgressBar::Base.new(:length => 100)
